StateAudioWeb class

Web binaural beat engine — uses Web Audio API OscillatorNodes routed through a ChannelMergerNode for true L/R separation.

Implemented types

Constructors

StateAudioWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
isPlaying bool
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
override
fadeOut({Duration duration = const Duration(seconds: 3)}) Future<void>
override
init() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
play({required double leftFreq, required double rightFreq, double volume = 0.7}) Future<void>
override
stop() Future<void>
override
toString() String
A string representation of this object.
inherited
updateFrequencies({required double leftFreq, required double rightFreq}) → void
override

Operators

operator ==(Object other) bool
The equality operator.
inherited