StateSessionLimiter class

Tracks daily free-state usage in Hive with in-memory cache.

Free states allow 1 session per state per day after the first ever use. The very first use of any state is always allowed (first-contact experience).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

canStart(String stateId) Future<bool>
Returns true if the user can start this free state right now.
recordSession(String stateId) Future<void>
Record that the user started a session for this state today.