SessionRecord class
A single recorded frequency state session.
Stored in Hive as JSON maps. Lightweight — no Firestore dependency.
Constructors
- SessionRecord({required String id, required String stateId, required DateTime startedAt, required DateTime completedAt, required int elapsedSeconds, required bool completedFull, String? emotion, double? avgHss, double? peakHss, double? historicTimePercent, int? contextRuptures})
-
const
-
SessionRecord.fromJson(Map<
String, dynamic> json) -
factory
Properties
- avgHss → double?
-
Optional biofeedback metrics (populated for historic descent sessions).
final
- completedAt → DateTime
-
final
- completedFull → bool
-
final
- contextRuptures → int?
-
final
- dateKey → String
-
no setter
- elapsed → Duration
-
no setter
- elapsedSeconds → int
-
final
- emotion → String?
-
final
- hasBiofeedback → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- historicTimePercent → double?
-
final
- id → String
-
final
- peakHss → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionDuration → Duration
-
no setter
- startedAt → DateTime
-
final
- stateId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited