visualLayerBuilder property
Optional visual experience overlay (injected from app layer). If null, only the photic pulse background is shown.
Implementation
final VisualLayerBuilder? visualLayerBuilder;
Optional visual experience overlay (injected from app layer). If null, only the photic pulse background is shown.
final VisualLayerBuilder? visualLayerBuilder;