StateCatalog class

All available frequency states, keyed by stateId.

These map directly to /x/{stateId} URLs.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

all List<FrequencyState>
no setter
free List<FrequencyState>
no setter
pro List<FrequencyState>
no setter

Static Methods

byId(String id) FrequencyState?