create constant
FrequencyState
const create
Implementation
static const create = FrequencyState(
id: 'create',
names: {'en': 'Creative Flow', 'es': 'Flujo Creativo', 'fr': 'Flux Créatif', 'de': 'Kreativfluss'},
descriptions: {
'en': 'Theta-Alpha border (7.5Hz). Targets the neural correlate of creative insight and divergent thinking. For writers, musicians, designers.',
'es': 'Frontera Theta-Alpha (7.5Hz). Apunta al correlato neural del insight creativo y pensamiento divergente. Para escritores, músicos, diseñadores.',
'fr': 'Frontière Theta-Alpha (7.5Hz). Cible le corrélat neural de l\'insight créatif et la pensée divergente.',
'de': 'Theta-Alpha-Grenze (7.5Hz). Zielt auf das neurale Korrelat kreativer Einsicht und divergenten Denkens.',
},
leftFrequency: 200,
rightFrequency: 207.5,
duration: Duration(minutes: 20),
screenColor: Color(0xFF2D1B69),
pulseFrequency: 0.5,
icon: Icons.palette,
isPro: true,
);